![cairo-lib logo](./img/cairo-lib-logo.png)

#### Libraries for Cairo development.

## Library

## Installation

To install with pip

```sh
pip install cairo-lib
```

To install with [**Hardhat**](https://github.com/nomiclabs/hardhat) or [**Truffle**](https://github.com/trufflesuite/truffle):

```sh
npm install cairo-lib
```

## Safety

This is **experimental software** and is provided on an "as is" and "as available" basis.

These **methods are NOT audited** and are **not designed with user safety** in mind:

We **do not give any warranties** and **will not be liable for any loss** incurred through any use of this codebase.

## Acknowledgements

These contracts were inspired by or directly modified from many sources, primarily:

- [StarkWare](https://github.com/starkware-libs/cairo-lang)
